@@ -118,7 +118,7 @@ class Phonetic_Manipulation():
 		self.ipa_p = self.ps['IPA'].tolist()
 		self.dm_p = self.dm['IPA'].tolist()
 		self.ipa_x = self.ps[phones].tolist()
-		self.dm_x = self.dm[phones].tolist()
+		self.dm_x = self.dm['X-SAMPA'].tolist()
 
 	def __clarify_phones__(self, df: pd.DataFrame, phones: str, *args) -> list:
 		"""
@@ -255,7 +255,7 @@ class Phonetic_Manipulation():
 		else:
 			self.diphthongs = self.vowels + '&' + self.vowels
 
-		consonants = self.ps.loc[(~vowelspace) & (~aff)][phones].tolist()
+		consonants = self.ps.loc[(~vowelspace)][phones].tolist()
 		self.consonants = '[' + ''.join(consonants) + ']'
 		self.consonants = re.sub(r'\\', r'\\\\', self.consonants)
 
